@@ -1,7 +1,7 @@
 autoevenn <-function(FolderPath="", pathRes="", annot=TRUE, ud=TRUE, prop=FALSE,
 		overlaps=FALSE, display=FALSE, couleurs="", VennBar=FALSE, transp=0.5,
 		Solid=TRUE, Profils=FALSE, ColorTxt="", colBlack=FALSE, Ptest=FALSE,
-		tUD=NULL, tUDp=NULL, tnoUD=NULL, Gtype="png",lw=1, NutShell=TRUE, VennClust=TRUE)
+		tUD=NULL, tUDp=NULL, tnoUD=NULL, Gtype="png",lw=1, NutShell=TRUE, VennClust=TRUE, OnlyVenn=FALSE)
 {
 	if(FolderPath=="")
 	{
@@ -29,6 +29,6 @@ autoevenn <-function(FolderPath="", pathRes="", annot=TRUE, ud=TRUE, prop=FALSE,
 		evenn(annot=annot, pathRes=FolderDest, pathLists=Venns[V], ud=ud, prop=prop, overlaps=overlaps,
 				display=display, couleurs=couleurs,	VennBar=VennBar, transp=transp, Solid=Solid,
 				Profils=Profils, ColorTxt=ColorTxt, colBlack=colBlack, Ptest=Ptest, tUD=tUD, 
-				tUDp=tUDp, tnoUD=tnoUD, Gtype=Gtype, lw=lw, NutShell=NutShell, VennClust=VennClust)
+				tUDp=tUDp, tnoUD=tnoUD, Gtype=Gtype, lw=lw, NutShell=NutShell, VennClust=VennClust, OnlyVenn=OnlyVenn)
 	}
 }
